#
# spec file for package crawl
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Sascha Peilicke <sasch.pe@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define about Crawl is a fun game in the grand tradition of games like Rogue, Hack, and Moria.\
Your objective is to travel deep into a subterranean cave complex and retrieve the Orb of Zot, \
which is guarded by many horrible and hideous creatures.
Name:           crawl
Version:        0.32.1
Release:        1.3
Summary:        Roguelike dungeon exploration game
License:        GPL-2.0-or-later
Group:          Amusements/Games/RPG
URL:            https://crawl.develz.org/
Source:         https://github.com/crawl/crawl/releases/download/%{version}/stone_soup-%{version}-nodeps.tar.xz
Patch0:         desktop.patch
Patch1:         icon.patch
Patch2:         appdata.patch
BuildRequires:  dejavu-fonts
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  lua51-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pngcrush
BuildRequires:  python3
BuildRequires:  python3-PyYAML
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sqlite3)
Requires:       %{name}-data = %{version}
Requires:       group(games)
Requires:       user(games)

%description
%{about}

This is the Stone Soup version of Dungeon Crawl.

Note: You need to be in the 'games' group in order to play the game.

%package sdl
Summary:        Roguelike dungeon exploration game (SDL version)
Group:          Amusements/Games/RPG
Requires:       %{name} = %{version}

%description sdl
%{about}

This is the (SDL-based) tiled Stone Soup version of Dungeon Crawl.

Note: You need to be in the 'games' group in order to play the game.

%package data
Summary:        Roguelike dungeon exploration game (Data files)
Group:          Amusements/Games/RPG
Requires:       %{name} = %{version}
BuildArch:      noarch

%description data
%{about}

These are the data files for Dungeon Crawl Stone Soup.

%prep
%autosetup -p1 -n stone_soup-%{version}

%build
cd source
tmpflags="%{optflags}"
%ifarch ppc64le
# avoid contentions between SDL vector and gcc defines
# disable the include of altivec.h in /usr/include/SDL2/SDL_cpuinfo.h
# note that --disable-altivec not supported by gcc 4.8
tmpflags="$tmpflags -U__ALTIVEC__"
%endif
%make_build clean
%make_build prefix=%{_prefix} bin_prefix=bin DATADIR="%{_datadir}/%{name}/" BINDIR=%{_bindir} EXTRA_FLAGS="${tmpflags}"
mv crawl crawl.tty # avoid name clashes temporarily
%make_build clean
%make_build prefix=%{_prefix} bin_prefix=bin DATADIR="%{_datadir}/%{name}/" BINDIR=%{_bindir} EXTRA_FLAGS="${tmpflags}" TILES="1"
mv crawl crawl-sdl
mv crawl.tty crawl

%pre
# move old saves
if [ -d %{_localstatedir}/games/crawl ]; then
	if [ -d /root/.crawl ]; then
		mv /root/.crawl /root/.crawl_old
	fi
	mv %{_localstatedir}/games/crawl /root/.crawl
fi

%install
%make_install -C source prefix=%{_prefix} bin_prefix=bin DATADIR=%{_datadir}/%{name} BINDIR=%{_bindir} TILES=y
install -D -m0644 docs/%{name}.6 %{buildroot}%{_mandir}/man6/%{name}.6
install -D -m0755 source/crawl-sdl %{buildroot}%{_bindir}/crawl-sdl
%fdupes %{buildroot}%{_datadir}/%{name}

%files sdl
%attr(0755,root,root) %{_bindir}/%{name}-sdl
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files data
%{_datadir}/%{name}

%files
%license LICENSE
%attr(0755,root,root) %{_bindir}/%{name}
%{_mandir}/man6/*

%changelog
* Fri Nov  1 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.32.1:
  * Fix blockable beam attacks from monster spells being blocked 100%% of the
    time.
  * 40 other bug fixes, interface improvements, and documentation updates.
- update to 0.32.0:
  * Beogh, Dithmenos, Yredelemnul, and Makhleb have been substantially revamped.
  * Since everybody can become orcs, reworked Mountain Dwarves replace Hill Orcs.
  * New species: Coglins, dual-wielding gizmo-inventing goblins in exosuits.
  * More new spells, aimed at new school combinations and higher levels.
  * Many more new and revamped monsters and decorations throughout the Dungeon,
    see full changelog at https://github.com/crawl/crawl/releases/tag/0.32.0
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.31.0:
  * Webtiles lobby idle timer, defaulting to 3 hours. This can be
    configured via the option `max_lobby_idle_time`.
  * Fixes to handling of idle crawl processes, process cleanup
  * Fixes to handling of a full disk
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sun Nov 12 2023 Dirk Müller <dmueller@suse.com>
- update to 0.30.1:
  * Fix zooming on local tiles
  * Many other bug and documentation fixes
  * New background: Reavers, spellswords with powerful but
    situational Conjurations.
  * Palentongas reworked into Armataurs, with innate rampage and
    an affinity for potions.
  * A variety of exciting new spells for warriors and wizards
    alike.
  * Many new and reworked artefacts, both random and fixed.
  * Lugonu made more available and tempting to unfortunates cast
    into the Abyss.
  * It is now possible to enter the Vaults without holding a
    rune. However, a rune is still required to leave.
  * Slime walls now apply corrosion to the player, rather than
    dealing damage.
  * Jiyva's Oozemancy ability still deals damage as before.
  * Thunderstorms now deal much more damage.
* Fri Jun 24 2022 Jon Brightwell <jon@moozaad.co.uk>
- Update to version 0.28.0
  Highlights
  * New Cinder Acolyte background, followers of the dying god Ignis.
  * The Hells burn with new fury, filled with new monsters and effects.
  * Yredelemnul completely redesigned; Okawaru and Jiyva significantly changed.
  * The Spider's Nest respun - many new monsters and maps lurk within.
  * Magical orbs added as a new category of off-hand equipment.
- Version 0.27 highlights
  * New species: Djinni.
  * Many new spells and spellbooks.
  * New monster sets and end maps for many branches.
  * Ashenzari completely redesigned and reworked.
  * Cursed items removed.
- Full changelogs at https://github.com/crawl/crawl/releases
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.26.1
  * ctrl-attack again no longer works while confused.
  * Console display flickering is reduced.
  * It is no longer possible to obtain infinite nets from net traps.
  * Various vault placement balance adjustments and teleport closet fixes.
  * 95 other fixes, tweaks, copy-edits, and interface improvements.
- Update to version 0.26.0
  * New species: Palentonga.
  * New background: Delver.
  * Food and hunger are removed.
  * Swamp has many new monsters and other changes.
  * Spells, wands, and abilities can be quivered, fired, and
    autotargeted with an extension of the ranged quiver/autofight
    interface.
  * Full log: https://github.com/crawl/crawl/releases/tag/0.26.0
- SPEC file: Drop parts related to outdated openSUSE versions
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.25.1
  * Change log see https://github.com/crawl/crawl/releases
  Highlights
  * Spells in many schools have been redesigned to make the schools
  more distinct.
  * Acquirement scrolls have been despoilered, offering the player
  a choice of generated items.
  * Effects from spell miscasts, god wrath, death curses, and Zot
  traps have been overhauled for consistency and simplicity.
- remove CVE-2020-11722.patch (fixed upstream)
* Tue Apr 14 2020 Ferdinand Thiessen <rpm@fthiessen.de>
- Added CVE-2020-11722.patch to fix CVE-2020-11722, boo#1169381
  * Fixes a remote code evaluation issue with lua loadstring
* Wed Mar 18 2020 Jon Brightwell <jon@moozaad.co.uk>
- Update to version 0.24.0
  * Vampire species simplified
  * Thrown weapons streamlined
  * Fedhas reimagined
  * Sif Muna reworked
- removed crawl-0.17.1-datetime.patch as fixed upstream
* Sun Jul 21 2019 Simon Puchert <simonpuchert@alice.de>
- Update to version 0.23.2
  * Trap system overhaul
  * New Gauntlet portal to replace Labyrinths
  * Nemelex Xobeh rework
  * Nine unrandarts reworked and the new "Rift" unrandart added
  * Support for seeded dungeon play
  * build requires python and python-pyYAML
* Sat Aug 25 2018 rpm@fthiessen.de
- Spec cleanup
  * Dropped defattr as more recent rpms add a default %%defattr line
    if none is present in the rpm %%files section
- Fixed source (used corret one from upstream)
* Fri Aug 10 2018 jon@moozaad.co.uk
- Update to 0.22.0
  * Player ghosts now only appear in sealed ghost vaults
  * New spell library interface
  * User interface revamp for Tiles and WebTiles
* Sat Jul 14 2018 jon@moozaad.co.uk
- Update to 0.21.1
* Thu Jul  6 2017 rpm@fthiessen.de
- Update to 0.20.1
* Tue May 16 2017 dimstar@opensuse.org
- On platforms > Leap 42.x/SLE12, require user(games) and
  group(games) instead of creating the user/group in pre.
* Sat Feb 18 2017 mailaender@opensuse.org
- Update to version 0.19.4
- Add desktop.patch for a menu starter
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
- Add icon.patch for installing a SVG icon
* Mon May  9 2016 steevstevep@gmail.com
- Update to 0.18.1
* Sat Jan  2 2016 opensuse@dstoecker.de
- do not compile date and time into the binary
  (crawl-0.17.1-datetime.patch)
* Mon Dec 14 2015 rpm@fthiessen.de
- Added fdupes and fixed usage of __DATE__ and __TIME__
* Mon Dec 14 2015 bemyak@gmail.com
- Updated to 0.17.1
* Mon Nov  9 2015 bemyak@gmail.com
- Updated to 0.17.0
* Thu Aug 27 2015 normand@linux.vnet.ibm.com
- for ppc64le architecture disable __ALTIVEC__ to avoid build error
  to avoid contention between SDL vector and gcc defines
* Mon Aug 24 2015 bemyak@gmail.com
- Updated to 0.16.2 (bugfix release)
* Sun Apr 12 2015 bemyak@gmail.com
- Removed _service, source archive is now attached directly
* Sat Apr 11 2015 bemyak@gmail.com
- Updated crawl to 0.16.1
- Source archive is now downloaded directly from crawl's website
* Wed Apr  8 2015 dimstar@opensuse.org
- Add a comment to the .desktop file (minimal requirement to show
  up in AppStream based software centers).
* Mon Mar 16 2015 bemyak@gmail.com
- Source URL corrected
* Sat Mar 14 2015 bemyak@gmail.com
- Updated crawl to 0.16.0
* Thu Nov  6 2014 bemyak@gmail.com
- Updated crawl to 0.15.2 (bugfix)
- Removed openSUSE 12.10, 11.* workarounds
- Removed crawl-ncurses-with-tinfo.patch,
  because tinfo included in ncurses by default
* Sun Sep 28 2014 mailaender@opensuse.org
- Updated to version 0.15.1
- avoid redundancy in %%description
* Thu Aug 28 2014 bemyak@gmail.com
- Updated crawl to 0.15
* Fri Jun 20 2014 devel.openSUSE.org@gmail.com
- Added crawl_24_gbdbe590.patch:
- Update to git master 0.14.1-24-gbdbe590:
  * Make drakes breathe, not throw (hangedman, Grunt)
  This was broken when the dragon genus was split.  I didn't restore
  the "roars" message, though.
  Also incorporates "Restrict drake breathe message to targeted spells."
  * Don't crash on t-r at the map edge (bh)
  * Fix an #ifdef (MarvinPA).
  * Include tileweb-text.cc in MSVC builds.
  * Add hash.cc to, remove obsolete files from, MSVC project.
  * Allow using Luajit on 64-bit systems (#8641)
  64-bit luajit doesn't support lua_newstate or custom allocators, so don't
  try to use one there.  However, give a warning if this happens with a
  webtiles or dgamelaunch build, because servers probably do want the
  memory throttling.
  * Don't crash on time step while siren-mesmerised (#8546)
  * Use the correct skill in variable-range rod spells (#8307)
  For the purposes of the hostile-in-range check and darken_beyond_range,
  we were computing power using the spell schools rather than Evocations.
  * More carefully chase item links in the pickup menu (#8603)
  Moving the item to the player destroyed it; normally that would have set
  the non-item's link to NON_ITEM, exiting the loop, but level excursions as
  part of pickup could overwrite the link.
  * Allow more than just the fallback hell entry in old late D.
  * Generate abyss/hell entries in old games with D:27.
  This includes generating hell entries on every level as we currently do in
  Depths.
  * Fix a bad array subscript (#8594)
  This has incorrectly been 9 rather than 0 since the function was added
  in 0.13-a0-927-g55b8bbf.
  * Replace a few uses of a <= b <= c (#8594)
  One of them was incorrect, and the other correct but confusing.
  * Fix a potential teleport closet (#8604)
  * Fix some Asterion speech. (MarvinPA, #8602)
  * Distinguish artefact from non- when swapping rings (#8062)
  If the left ring was a artefact and the right ring a non-artefact of the
  same base time, we failed to ask which to swap out.
  * Time-out unintentional Vp bat form normally (#8392)
  * Remove mention of ! from tutorial/hints skills screen (#5346).
  According to b702f4e, this menu is supposed to be disabled because it
  explains advanced commands which aren't available in the simple menu,
  * Allow toggling skill practicing in tutorial/hints mode again.
  Broken by ecaf8b2.
  It's a sad state of affairs that nobody thought this was a bug for
  almost three years.
  * Mention some 0.13 changes in the changelog (#7000).
  * Don't allow wielding an item that's too large while transformed.
  * Relevant for tree-form.
  * tilepick-p.cc: fix SP_NAGA switch fallthrough
  * Don't crash when mousing over remembered-but-gone webs (#8429)
  * Remove some residual item race references (#8480).
* Mon Jun  9 2014 bemyak@gmail.com
- Now saves located in ~/.crawl dir. This mean:
  * Different users now uses different settings
  * Users can now change setting without root privilages
  (by creating ~/.crawl/init.txt or ~/.crawlrc file)
- Old saves moved to /root/.crawl directory
* Fri May 23 2014 bemyak@gmail.com
- version 0.14.1
- Adapt crawl-ncurses-with-tinfo.patch to new version of the game
* Mon Sep 23 2013 idonmez@suse.com
- Create games user/group on demand. fate#314560
* Wed Jun 19 2013 crrodriguez@opensuse.org
- version 0.12.1
  * add buildrequire to sqlite-devel and dejavu fonts.
  * fix build with gcc 48
- Fixed multiple issues on big-endian systems.
- Misc crash fixes
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit glu dependency to fix the build for Factory
* Fri Jul  6 2012 devel.openSUSE.org@gmail.com
- Updated to version 0.10.3:
  * Crash fixes.
  * rPois- doesn't grant rPois+ for potions of poison.
  * Clean chunks are no longer better than permafood when nauseated.
  * The Flight spell is no longer cancellable (could cause a death when
    swapping a +Lev item above water due to incorrect assumptions).
  * A warning when transforming would meld your last +Lev item.
  * Backlash works for finding portals on the map screen.
  * Remembered traps no longer lose their identity when out of sight.
  * Certain rare monsters don't clutter tile displays with name tags anymore.
  * show_game_turns labels its display as "Time:" not "Turn:".
  * Greatly improved webtiles performance.
  * Fixed miscompiles or compilation failures with GCC 4.7.
  * A bunch of assorted minor fixes.
  * Some new interface functionality:
  * can annotate remote levels (X[ then !)
  * picking a stack of items you already had some of shows how many did you
    just gain
  * shops show item slot letters assigned to your new purchases
  * enchanteable missiles are listed in the wield menu if you have scrolls
    of Enchant Weapon
- Adapt crawl-ncurses-with-tinfo.patch to new version of the game
* Tue Feb 21 2012 saschpe@suse.de
- BuildRequire lua51-devel on openSUSE > 12.1
* Wed Nov 23 2011 jreidinger@suse.com
- fix build for older distributions( old ncurses doesn't have
  separated tinfo )
* Tue Nov 22 2011 saschpe@suse.de
- Set license to SDPX style (GPL-2.0+)
- Add crawl-ncurses-with-tinfo.patch to link against tinfo
* Fri Sep  9 2011 saschpe@suse.de
- Update to version 0.9.1:
  * Fix missing portals to Zot on D:27 with restart_after_game after Sprint.
  * Fix most large special maps not being generated.
  * Fix mad amounts of divine gifts in certain cases.
  * Don’t duplicate monsters when exiting the Abyss.
  * Fix a lock-up on selecting a random character.
  * A number of crash fixes.
  * Some documentation amendments.
  * Don’t stop butchering on unimportant messages.
  * Add a command “show runes” (‘}’) that was documented but not implemented.
- Changes from previous version, see doc/changelog.txt
* Thu Mar  3 2011 saschpe@suse.de
- cleaned up spec file.
* Fri Feb 25 2011 saschpe@suse.de
- update to upstream version 0.7.2
  * fix a variety of crash bugs.
  * fix weapon acquirement not considering some rare weapons.
  * fix problems with Unicode locales other than en_US.UTF-8.
  * fix near-uselessness on ARM.
  * a variety of other bug fixes.
* Mon Aug  2 2010 sasch.pe@gmx.de
- updated to upstream version 0.7.1
* Thu Apr  8 2010 sasch.pe@gmx.de
- desktop file is now also installed correctly for Fedora builds
* Tue Apr  6 2010 sasch.pe@gmx.de
- changed executable ownership to 'root:root' and flags to '0755'
* Tue Apr  6 2010 sasch.pe@gmx.de
- fixed data package ownership and install rules
- expanded data package description
* Wed Mar 31 2010 prusnak@suse.cz
- cleanup spec file, don't install into /usr/games and /usr/share/games
* Wed Mar 31 2010 sasch.pe@gmx.de
- changed build requirements to support Fedora and Mandriva
- renamed desktop entry name to "Dungeon Crawl Stone Soup (SDL)"
- crawl-sdl package now requires the correct base package version
* Wed Mar 31 2010 sasch.pe@gmx.de
- added 'group' field in crawl-sdl package
* Tue Mar 30 2010 sasch.pe@gmx.de
- updated to upstream version 0.6.0
- moved SDL version into own package
* Wed Aug  5 2009 sasch.pe@gmx.de
- corrected .desktop file automatic translation in the spec file
* Wed Aug  5 2009 sasch.pe@gmx.de
- added SDL version
- added icon and .desktop file for the SDL version
* Tue Aug  4 2009 sasch.pe@gmx.de
- initial checkin of version 0.5.1
* Wed Apr 29 2009 sasch.pe@gmx.de
- first release (version 0.5.0)
